@@ -39,7 +39,7 @@ class LogstashClient(NamespacedClient):
         """
         Deletes Logstash Pipelines used by Central Management
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/logstash-api-delete-pipeline.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/logstash-api-delete-pipeline.html>`_
 
         :param id: The ID of the Pipeline
         """
@@ -75,13 +75,16 @@ class LogstashClient(NamespacedClient):
         """
         Retrieves Logstash Pipelines used by Central Management
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/logstash-api-get-pipeline.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/logstash-api-get-pipeline.html>`_
 
         :param id: A comma-separated list of Pipeline IDs
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
-        __path = f"/_logstash/pipeline/{_quote(id)}"
+        if id not in SKIP_IN_PATH:
+            __path = f"/_logstash/pipeline/{_quote(id)}"
+        else:
+            __path = "/_logstash/pipeline"
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
             __query["error_trace"] = error_trace
@@ -114,7 +117,7 @@ class LogstashClient(NamespacedClient):
         """
         Adds and updates Logstash Pipelines used for Central Management
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/logstash-api-put-pipeline.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.7/logstash-api-put-pipeline.html>`_
 
         :param id: The ID of the Pipeline
         :param pipeline:
